"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _ipc = require("./ipc");

var _prevalError = require("./preval-error");

function createNextPluginPreval({ // ...other options in the future
  ...ipcOptions
} = {}) {
  function withNextPluginPreval(_nextConfig) {
    const normalizedNextConfig = typeof _nextConfig === 'function' ? _nextConfig : () => _nextConfig || {};
    return (...args) => {
      const nextConfig = normalizedNextConfig(...args);
      let ipcServerId;
      return { ...nextConfig,
        // hi-jack `generateBuildId` because it allows a promise,
        // the `webpack` config option does not allow promises
        generateBuildId: async (...args) => {
          var _nextConfig$generateB;

          // sneak in an await here
          ipcServerId = await (0, _ipc.createIpcServer)(ipcOptions); // then run the provided `generateBuildId` function

          const buildId = await ((_nextConfig$generateB = nextConfig.generateBuildId) === null || _nextConfig$generateB === void 0 ? void 0 : _nextConfig$generateB.call(nextConfig, ...args));
          return buildId || null;
        },
        webpack: (config, options) => {
          var _nextConfig$webpack, _webpackConfig$module;

          // this should always be defined because of the above.
          if (!ipcServerId) {
            throw new _prevalError.PrevalError('Next Plugin Preval could not to start IPC caching server before webpack ran. Please file an issue.');
          }

          const webpackConfig = ((_nextConfig$webpack = nextConfig.webpack) === null || _nextConfig$webpack === void 0 ? void 0 : _nextConfig$webpack.call(nextConfig, config, options)) || config;
          const rules = (_webpackConfig$module = webpackConfig.module) === null || _webpackConfig$module === void 0 ? void 0 : _webpackConfig$module.rules;

          if (!rules) {
            throw new _prevalError.PrevalError('Next Plugin Preval could not find webpack rules. Please file an issue.');
          }

          rules.push({
            test: /\.preval\.(t|j)sx?$/,
            loader: require.resolve('./loader'),
            options: {
              ipcServerId,
              ipcOptions
            }
          });
          return webpackConfig;
        }
      };
    };
  }

  return withNextPluginPreval;
}

var _default = createNextPluginPreval;
exports.default = _default;
//# sourceMappingURL=create-next-plugin-preval.js.map