declare type IpcRequest = {
    resource: string;
};
declare type IpcResponse = {
    result: unknown;
};
export interface IpcOptions {
    /**
     * Provide options to `node-ipc` such as enabling the logger by setting
     * `nodeIpcConfig: {silent: false}`
     *
     * See here: https://github.com/RIAEvangelist/node-ipc#ipc-config
     */
    nodeIpcConfig?: Partial<typeof import('node-ipc')['config']>;
}
/**
 * Creates an inter-process communication server between the main build process
 * and separate processes created by next.js for generating pages in parallel.
 *
 * This uses the package [`node-ipc`][gh] and uses Unix sockets/Windows
 * sockets to communicate. A socket ID (to be passed to `createIpcClient`) is
 * returned
 *
 * [gh]: https://github.com/RIAEvangelist/node-ipc
 */
export declare function createIpcServer({ nodeIpcConfig, }?: IpcOptions): Promise<string>;
/**
 * Creates an inter-process communication client between the main build process
 * and separate processes created by next.js for generating pages in parallel.
 *
 * This uses the package [`node-ipc`][gh] and uses Unix sockets/Windows
 * sockets to communicate. Takes in a socket ID and returns an object with a
 * request function.
 *
 * [gh]: https://github.com/RIAEvangelist/node-ipc
 */
export declare function createIpcClient(id: string, { nodeIpcConfig }?: IpcOptions): Promise<{
    request: (requestBody: IpcRequest) => Promise<IpcResponse>;
}>;
export {};
