"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports._prevalLoader = _prevalLoader;
exports.default = void 0;

var _loaderUtils = require("loader-utils");

var _ipc = require("./ipc");

var _prevalError = require("./preval-error");

async function _prevalLoader(_, resource, {
  ipcServerId,
  ipcOptions
}) {
  const client = await (0, _ipc.createIpcClient)(ipcServerId, ipcOptions);
  const {
    result
  } = await client.request({
    resource
  }); // NOTE we wrap in JSON.parse because that's faster for JS engines to parse
  // over javascript. see here https://v8.dev/blog/cost-of-javascript-2019#json
  //
  // We wrap in JSON.stringify twice. Once for a JSON string and once again for
  // a JSON string that can be embeddable in javascript.

  return `module.exports = JSON.parse(${JSON.stringify(JSON.stringify(result))})`;
}

const loader = function (content) {
  const callback = this.async();
  this.cacheable(false);

  if (!callback) {
    throw new _prevalError.PrevalError('Async was not supported by webpack. Please open an issue in next-plugin-preval.');
  }

  _prevalLoader(content.toString(), this.resourcePath, (0, _loaderUtils.getOptions)(this)).then(result => {
    callback(null, result);
  }).catch(e => {
    callback(e);
  });
};

var _default = loader;
exports.default = _default;
//# sourceMappingURL=loader.js.map